<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Katha Pro
 * @since Katha Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'katha_pro_about_section', array(
	'title'             => esc_html__( 'About Us','katha-pro' ),
	'description'       => esc_html__( 'About Section options.', 'katha-pro' ),
	'panel'             => 'katha_pro_front_page_panel',
) );

// About content enable control and setting
$wp_customize->add_setting( 'katha_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'katha_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Katha_Pro_Switch_Control( $wp_customize, 'katha_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'katha-pro' ),
	'section'           => 'katha_pro_about_section',
	'on_off_label' 		=> katha_pro_switch_options(),
) ) );

// About content type control and setting
$wp_customize->add_setting( 'katha_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'katha_pro_sanitize_select',
) );

$wp_customize->add_control( 'katha_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'katha-pro' ),
	'section'           => 'katha_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'katha_pro_is_about_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'katha-pro' ),
		'post' 		=> esc_html__( 'Post', 'katha-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'katha-pro' ),
	),
) );

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'katha_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'katha_pro_sanitize_page',
) );

$wp_customize->add_control( new Katha_Pro_Dropdown_Chooser( $wp_customize, 'katha_pro_theme_options[about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'katha-pro' ),
	'section'           => 'katha_pro_about_section',
	'choices'			=> katha_pro_page_choices(),
	'active_callback'	=> 'katha_pro_is_about_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'katha_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'katha_pro_sanitize_page',
) );

$wp_customize->add_control( new Katha_Pro_Dropdown_Chooser( $wp_customize, 'katha_pro_theme_options[about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'katha-pro' ),
	'section'           => 'katha_pro_about_section',
	'choices'			=> katha_pro_post_choices(),
	'active_callback'	=> 'katha_pro_is_about_section_content_post_enable',
) ) );

// about title setting and control
$wp_customize->add_setting( 'katha_pro_theme_options[about_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'katha_pro_theme_options[about_title]', array(
	'label'           	=> esc_html__( 'Title', 'katha-pro' ),
	'section'        	=> 'katha_pro_about_section',
	'active_callback' 	=> 'katha_pro_is_about_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'katha_pro_theme_options[about_title]', array(
		'selector'            => '#about-us .entry-container .entry-title',
		'settings'            => 'katha_pro_theme_options[about_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'katha_pro_about_title_partial',
    ) );
}

// about link setting and control
$wp_customize->add_setting( 'katha_pro_theme_options[about_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	'default'			=> $options['about_link'],
) );

$wp_customize->add_control( 'katha_pro_theme_options[about_link]', array(
	'label'           	=> esc_html__( 'Link', 'katha-pro' ),
	'section'        	=> 'katha_pro_about_section',
	'active_callback' 	=> 'katha_pro_is_about_section_content_custom_enable',
	'type'				=> 'url',
) );

// about link setting and control
$wp_customize->add_setting( 'katha_pro_theme_options[about_content]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['about_content'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'katha_pro_theme_options[about_content]', array(
	'label'           	=> esc_html__( 'Description', 'katha-pro' ),
	'section'        	=> 'katha_pro_about_section',
	'active_callback' 	=> 'katha_pro_is_about_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'katha_pro_theme_options[about_content]', array(
		'selector'            => '#about-us .entry-container .entry-content p',
		'settings'            => 'katha_pro_theme_options[about_content]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'katha_pro_about_content_partial',
    ) );
}

// about title setting and control
$wp_customize->add_setting( 'katha_pro_theme_options[about_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_btn_label'],
	'transport'			=> 'postMessage',

) );

$wp_customize->add_control( 'katha_pro_theme_options[about_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'katha-pro' ),
	'section'        	=> 'katha_pro_about_section',
	'active_callback' 	=> 'katha_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'katha_pro_theme_options[about_btn_label]', array(
		'selector'            => '#about-us .entry-container .entry-content a.btn',
		'settings'            => 'katha_pro_theme_options[about_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'katha_pro_about_btn_label_partial',
    ) );
}
