<?php
/**
 * Blog Section options
 *
 * @package Theme Palace
 * @subpackage Katha Pro
 * @since Katha Pro 1.0.0
 */

// Add Blog section
$wp_customize->add_section( 'katha_pro_blog_section', array(
	'title'             => esc_html__( 'Blog','katha-pro' ),
	'description'       => esc_html__( 'Blog Section options.', 'katha-pro' ),
	'panel'             => 'katha_pro_front_page_panel',
) );

// Blog content enable control and setting
$wp_customize->add_setting( 'katha_pro_theme_options[blog_section_enable]', array(
	'default'			=> 	$options['blog_section_enable'],
	'sanitize_callback' => 'katha_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Katha_Pro_Switch_Control( $wp_customize, 'katha_pro_theme_options[blog_section_enable]', array(
	'label'             => esc_html__( 'Blog Section Enable', 'katha-pro' ),
	'section'           => 'katha_pro_blog_section',
	'on_off_label' 		=> katha_pro_switch_options(),
) ) );

// Blog content type control and setting
$wp_customize->add_setting( 'katha_pro_theme_options[blog_content_type]', array(
	'default'          	=> $options['blog_content_type'],
	'sanitize_callback' => 'katha_pro_sanitize_select',
) );

$wp_customize->add_control( 'katha_pro_theme_options[blog_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'katha-pro' ),
	'section'           => 'katha_pro_blog_section',
	'type'				=> 'select',
	'active_callback' 	=> 'katha_pro_is_blog_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'katha-pro' ),
		'post' 		=> esc_html__( 'Post', 'katha-pro' ),
		'category' 	=> esc_html__( 'Category', 'katha-pro' ),
		'recent' 	=> esc_html__( 'Recent', 'katha-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'katha_pro_theme_options[blog_count]', array(
	'default'          	=> $options['blog_count'],
	'sanitize_callback' => 'katha_pro_sanitize_number_range',
	'validate_callback' => 'katha_pro_validate_blog_count',
) );

$wp_customize->add_control( 'katha_pro_theme_options[blog_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'katha-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'katha-pro' ),
	'section'           => 'katha_pro_blog_section',
	'active_callback'   => 'katha_pro_is_blog_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['blog_count']; $i++ ) :
	// blog pages drop down chooser control and setting
	$wp_customize->add_setting( 'katha_pro_theme_options[blog_content_page_' . $i . ']', array(
		'sanitize_callback' => 'katha_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Katha_Pro_Dropdown_Chooser( $wp_customize, 'katha_pro_theme_options[blog_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'katha-pro' ), $i ),
		'section'           => 'katha_pro_blog_section',
		'choices'			=> katha_pro_page_choices(),
		'active_callback'	=> 'katha_pro_is_blog_section_content_page_enable',
	) ) );

	// blog posts drop down chooser control and setting
	$wp_customize->add_setting( 'katha_pro_theme_options[blog_content_post_' . $i . ']', array(
		'sanitize_callback' => 'katha_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Katha_Pro_Dropdown_Chooser( $wp_customize, 'katha_pro_theme_options[blog_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'katha-pro' ), $i ),
		'section'           => 'katha_pro_blog_section',
		'choices'			=> katha_pro_post_choices(),
		'active_callback'	=> 'katha_pro_is_blog_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'katha_pro_theme_options[blog_content_category]', array(
	'sanitize_callback' => 'katha_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Katha_Pro_Dropdown_Taxonomies_Control( $wp_customize,'katha_pro_theme_options[blog_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'katha-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'katha-pro' ),
	'section'           => 'katha_pro_blog_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'katha_pro_is_blog_section_content_category_enable'
) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'katha_pro_theme_options[blog_category_exclude]', array(
	'sanitize_callback' => 'katha_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Katha_Pro_Dropdown_Category_Control( $wp_customize,'katha_pro_theme_options[blog_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'katha-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Shift key select multilple categories.', 'katha-pro' ),
	'section'           => 'katha_pro_blog_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'katha_pro_is_blog_section_content_recent_enable'
) ) );
