<?php
/**
 * Featured Section options
 *
 * @package Theme Palace
 * @subpackage Katha Pro
 * @since Katha Pro 1.0.0
 */

// Add Featured section
$wp_customize->add_section( 'katha_pro_featured_section', array(
	'title'             => esc_html__( 'Featured','katha-pro' ),
	'description'       => esc_html__( 'Featured Section options.', 'katha-pro' ),
	'panel'             => 'katha_pro_front_page_panel',
) );

// Featured content enable control and setting
$wp_customize->add_setting( 'katha_pro_theme_options[featured_section_enable]', array(
	'default'			=> 	$options['featured_section_enable'],
	'sanitize_callback' => 'katha_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Katha_Pro_Switch_Control( $wp_customize, 'katha_pro_theme_options[featured_section_enable]', array(
	'label'             => esc_html__( 'Featured Section Enable', 'katha-pro' ),
	'section'           => 'katha_pro_featured_section',
	'on_off_label' 		=> katha_pro_switch_options(),
) ) );

// Featured count control and setting
$wp_customize->add_setting( 'katha_pro_theme_options[featured_count]', array(
	'default'          	=> $options['featured_count'],
	'sanitize_callback' => 'katha_pro_sanitize_number_range',
	'validate_callback' => 'katha_pro_validate_featured_count',
) );

$wp_customize->add_control( 'katha_pro_theme_options[featured_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'katha-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 4. Please input the valid number and save. Then refresh the page to see the change.', 'katha-pro' ),
	'section'           => 'katha_pro_featured_section',
	'active_callback'   => 'katha_pro_is_featured_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 4,
		'style' => 'width: 100px;'
		),
) );

// Featured content type control and setting
$wp_customize->add_setting( 'katha_pro_theme_options[featured_content_type]', array(
	'default'          	=> $options['featured_content_type'],
	'sanitize_callback' => 'katha_pro_sanitize_select',
) );

$wp_customize->add_control( 'katha_pro_theme_options[featured_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'katha-pro' ),
	'section'           => 'katha_pro_featured_section',
	'type'				=> 'select',
	'active_callback' 	=> 'katha_pro_is_featured_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'katha-pro' ),
		'post' 		=> esc_html__( 'Post', 'katha-pro' ),
		'category' 	=> esc_html__( 'Category', 'katha-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'katha-pro' ),
	),
) );

for ( $i = 1; $i <= $options['featured_count']; $i++ ) {
	// featured pages drop down chooser control and setting
	$wp_customize->add_setting( 'katha_pro_theme_options[featured_content_page_' . $i . ']', array(
		'sanitize_callback' => 'katha_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Katha_Pro_Dropdown_Chooser( $wp_customize, 'katha_pro_theme_options[featured_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'katha-pro' ), $i ),
		'section'           => 'katha_pro_featured_section',
		'choices'			=> katha_pro_page_choices(),
		'active_callback'	=> 'katha_pro_is_featured_section_content_page_enable',
	) ) );

	// featured posts drop down chooser control and setting
	$wp_customize->add_setting( 'katha_pro_theme_options[featured_content_post_' . $i . ']', array(
		'sanitize_callback' => 'katha_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Katha_Pro_Dropdown_Chooser( $wp_customize, 'katha_pro_theme_options[featured_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'katha-pro' ), $i ),
		'section'           => 'katha_pro_featured_section',
		'choices'			=> katha_pro_post_choices(),
		'active_callback'	=> 'katha_pro_is_featured_section_content_post_enable',
	) ) );

	// featured title setting and control
	$wp_customize->add_setting( 'katha_pro_theme_options[featured_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'katha_pro_theme_options[featured_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Title %d', 'katha-pro' ), $i ),
		'section'        	=> 'katha_pro_featured_section',
		'active_callback' 	=> 'katha_pro_is_featured_section_content_custom_enable',
		'type'				=> 'text',
	) );

	// featured link setting and control
	$wp_customize->add_setting( 'katha_pro_theme_options[featured_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'katha_pro_theme_options[featured_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Link %d', 'katha-pro' ), $i ),
		'section'        	=> 'katha_pro_featured_section',
		'active_callback' 	=> 'katha_pro_is_featured_section_content_custom_enable',
		'type'				=> 'url',
	) );

	// featured image setting and control.
	$wp_customize->add_setting( 'katha_pro_theme_options[featured_image_' . $i . ']', array(
		'sanitize_callback' => 'katha_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'katha_pro_theme_options[featured_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'katha-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'katha-pro' ), 587, 775 ),
			'section'     		=> 'katha_pro_featured_section',
			'active_callback'	=> 'katha_pro_is_featured_section_content_custom_enable',
	) ) );

	// featured hr control and setting
	$wp_customize->add_setting( 'katha_pro_theme_options[featured_hr_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Katha_Pro_Customize_Horizontal_Line( $wp_customize, 'katha_pro_theme_options[featured_hr_' . $i . ']', array(
		'section'           => 'katha_pro_featured_section',
		'active_callback'	=> 'katha_pro_is_featured_section_content_custom_enable',
		'type'			    => 'hr'
	) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'katha_pro_theme_options[featured_content_category]', array(
	'sanitize_callback' => 'katha_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Katha_Pro_Dropdown_Taxonomies_Control( $wp_customize,'katha_pro_theme_options[featured_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'katha-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'katha-pro' ),
	'section'           => 'katha_pro_featured_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'katha_pro_is_featured_section_content_category_enable'
) ) );